import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }

function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }

import { createBEM } from '@zarm-design/bem';
import { Minus as MinusIcon, Success as SuccessIcon } from '@zarm-design/icons';
import includes from 'lodash/includes';
import React, { forwardRef, useContext, useEffect, useImperativeHandle, useRef, useState } from 'react';
import Button from '../button';
import { ConfigContext } from '../config-provider';
import List from '../list';
import { CheckboxGroupContext } from './context';

var getChecked = function getChecked(props, defaultChecked) {
  var _ref, _props$checked;

  return (_ref = (_props$checked = props.checked) !== null && _props$checked !== void 0 ? _props$checked : props.defaultChecked) !== null && _ref !== void 0 ? _ref : defaultChecked;
};

;
var Checkbox = /*#__PURE__*/forwardRef(function (props, ref) {
  var inputRef = useRef(null);

  var _useState = useState(getChecked(props, false)),
      _useState2 = _slicedToArray(_useState, 2),
      checked = _useState2[0],
      setChecked = _useState2[1];

  var disabled = props.disabled;
  var groupContext = useContext(CheckboxGroupContext);

  if (groupContext && props.value !== undefined) {
    checked = includes(groupContext.value, props.value);

    setChecked = function setChecked(changedChecked) {
      if (changedChecked) {
        groupContext.check(props.value);
      } else {
        groupContext.uncheck(props.value);
      }
    };

    disabled = disabled || groupContext.disabled;
  }

  var _useContext = useContext(ConfigContext),
      prefixCls = _useContext.prefixCls;

  var bem = createBEM('checkbox', {
    prefixCls: prefixCls
  });
  var cls = bem([{
    disabled: disabled,
    checked: checked && !props.indeterminate,
    untext: !props.children,
    indeterminate: props.indeterminate
  }, props.className]);

  var currentProps = _objectSpread(_objectSpread({}, props), {}, {
    checked: checked
  });

  var textRender = props.children && /*#__PURE__*/React.createElement("span", {
    className: bem('text')
  }, props.children);
  var iconRender = /*#__PURE__*/React.createElement("span", {
    className: bem('icon')
  }, props.renderIcon ? props.renderIcon(currentProps) : /*#__PURE__*/React.createElement("span", {
    className: bem('tick')
  }, props.indeterminate ? /*#__PURE__*/React.createElement(MinusIcon, null) : /*#__PURE__*/React.createElement(SuccessIcon, null)));
  var inputRender = /*#__PURE__*/React.createElement("input", {
    ref: inputRef,
    id: props.id,
    type: "checkbox",
    className: bem('input'),
    "aria-checked": checked,
    disabled: disabled,
    value: props.value,
    checked: checked,
    onChange: function onChange(e) {
      var _props$onChange;

      if (disabled) return;

      if (!('checked' in props)) {
        setChecked(e.target.checked);
      }

      (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, e);
    }
  });
  useImperativeHandle(ref, function () {
    return {
      check: function check() {
        if (checked) return;
        inputRef.current.click();
      },
      uncheck: function uncheck() {
        if (!checked) return;
        inputRef.current.click();
      },
      toggle: function toggle() {
        inputRef.current.click();
      }
    };
  });
  useEffect(function () {
    if (props.checked === undefined) return;
    if (props.checked === checked) return;
    setChecked(getChecked({
      checked: props.checked,
      defaultChecked: props.defaultChecked
    }, false));
  }, [props.checked, props.defaultChecked]);

  if ((groupContext === null || groupContext === void 0 ? void 0 : groupContext.type) === 'button') {
    return /*#__PURE__*/React.createElement("label", {
      className: cls,
      style: props.style
    }, inputRender, /*#__PURE__*/React.createElement(Button, {
      disabled: disabled,
      theme: checked ? 'primary' : 'default',
      size: "xs",
      block: groupContext === null || groupContext === void 0 ? void 0 : groupContext.block,
      onClick: function onClick() {
        inputRef.current.click();
      }
    }, props.children));
  }

  if ((groupContext === null || groupContext === void 0 ? void 0 : groupContext.type) === 'list') {
    var tickRender = /*#__PURE__*/React.createElement(React.Fragment, null, inputRender, iconRender);
    return /*#__PURE__*/React.createElement(List.Item, {
      hasArrow: false,
      className: cls,
      style: props.style,
      prefix: (groupContext === null || groupContext === void 0 ? void 0 : groupContext.iconAlign) === 'before' ? tickRender : undefined,
      suffix: (groupContext === null || groupContext === void 0 ? void 0 : groupContext.iconAlign) === 'after' ? tickRender : undefined,
      title: textRender,
      onClick: !disabled ? function () {
        if (disabled) return;
        inputRef.current.click();
      } : undefined
    });
  }

  var contentRender = props.render ? props.render(currentProps) : /*#__PURE__*/React.createElement(React.Fragment, null, iconRender, textRender);
  return /*#__PURE__*/React.createElement("label", {
    className: cls,
    style: props.style
  }, inputRender, contentRender);
});
Checkbox.displayName = 'Checkbox';
Checkbox.defaultProps = {
  indeterminate: false
};
export default Checkbox;