import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }

function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }

import React from 'react';
import { fireEvent, render } from '@testing-library/react';
import { mocked } from 'ts-jest/utils';
import FilePicker from '../index';
import { mockCreateObjectURL, mockResetCreateObjectURL } from '../../../tests/utils';
import handleFileInfo from '../utils/handleFileInfo';
jest.mock('../utils/handleFileInfo');
var mHandleFileInfo = mocked(handleFileInfo);
describe('file picker', function () {
  it('render correctly', function () {
    var props = {
      onChange: jest.fn(),
      children: /*#__PURE__*/React.createElement("button", null, "add")
    };
    var wrapper = render( /*#__PURE__*/React.createElement(FilePicker, props));
    expect(wrapper.asFragment()).toMatchSnapshot();
  });
});
describe('file picker event', function () {
  var props = {
    accept: 'image/jpg, image/jpeg, image/gif, image/png',
    onChange: jest.fn(),
    quality: 0.3,
    children: /*#__PURE__*/React.createElement("button", null, "add")
  };
  var mCreateObjectURL = jest.fn();
  var file = new File([''], './test.jpg', {
    type: 'image/jpeg'
  });
  var mFileDetail = {
    file: file,
    fileType: file.type,
    fileName: file.name,
    fileSize: file.size,
    thumbnail: 'data:,'
  };
  beforeAll(function () {
    mockCreateObjectURL(mCreateObjectURL);
  });
  afterAll(function () {
    mockResetCreateObjectURL();
  });
  afterEach(function () {
    jest.clearAllMocks();
  });
  it('select image & onBeforeSelect is not func', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      multiple: true,
      onBeforeSelect: false
    });

    mHandleFileInfo.mockImplementation(function (_, callback) {
      callback(mFileDetail);
    });

    var _render = render( /*#__PURE__*/React.createElement(FilePicker, _props)),
        container = _render.container;

    var mClickEvent = {
      preventDefault: jest.fn()
    };
    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput, mClickEvent);
    expect(mClickEvent.preventDefault).not.toBeCalled();
    fireEvent.change(fileInput, {
      target: {
        files: [file]
      }
    });
    expect(props.onChange).toBeCalledWith([mFileDetail]);
    expect(props.onChange).toBeCalledTimes(1);
  });
  it('should handle change event if files is an array of File instance', function () {
    var getFileInfo;
    mHandleFileInfo.mockImplementation(function (_, callback) {
      getFileInfo = callback;
      callback(mFileDetail);
    });

    var _render2 = render( /*#__PURE__*/React.createElement(FilePicker, props)),
        container = _render2.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput, {
      target: {
        files: [file]
      }
    });
    expect(mHandleFileInfo).toBeCalledWith({
      file: file,
      quality: 0.3
    }, getFileInfo);
    expect(props.onChange).toBeCalledWith(mFileDetail);
  });
  it('click children', function () {
    var _render3 = render( /*#__PURE__*/React.createElement(FilePicker, props)),
        container = _render3.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput, {
      target: {
        files: [file]
      }
    });
    expect(props.onChange).toBeCalled();
  });
});
describe('file picker disabled', function () {
  var props = {
    accept: 'image/jpg, image/jpeg, image/gif, image/png',
    onChange: jest.fn(),
    onBeforeSelect: jest.fn(),
    children: /*#__PURE__*/React.createElement("button", null, "foo")
  };
  it('on before select return false', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      onBeforeSelect: jest.fn(function () {
        return false;
      })
    });

    var _render4 = render( /*#__PURE__*/React.createElement(FilePicker, _props)),
        container = _render4.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput);
    expect(props.onChange).not.toHaveBeenCalled();
  });
  it('disabled', function () {
    var _props = _objectSpread(_objectSpread({}, props), {}, {
      disabled: true
    });

    var _render5 = render( /*#__PURE__*/React.createElement(FilePicker, _props)),
        container = _render5.container;

    var fileInput = container.querySelectorAll('.za-file-picker__input')[0];
    fireEvent.change(fileInput);
    expect(props.onChange).not.toHaveBeenCalled();
  });
});