"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _classnames2 = _interopRequireDefault(require("classnames"));

var React = _interopRequireWildcard(require("react"));

var _reactTransitionGroup = require("react-transition-group");

var _utils = require("../utils");

var _events = _interopRequireDefault(require("../utils/events"));

function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }

function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) { if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } } return n.default = e, t && t.set(e, n), n; }

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }

function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2.default)(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }

var TransitionState;

(function (TransitionState) {
  TransitionState["UNMOUNTED"] = "unmounted";
  TransitionState["ENTER"] = "enter";
  TransitionState["ENTERING"] = "entering";
  TransitionState["ENTERED"] = "entered";
  TransitionState["EXIT"] = "exit";
  TransitionState["EXITING"] = "exiting";
  TransitionState["EXITED"] = "exited";
})(TransitionState || (TransitionState = {}));

var animationEndName = 'animationend';
var transitionEndName = 'transitionend';

var Transition = function Transition(props) {
  var _classnames;

  var visible = props.visible,
      tranisitionName = props.tranisitionName,
      duration = props.duration,
      forceRender = props.forceRender,
      destroy = props.destroy,
      children = props.children,
      _onEnter = props.onEnter,
      onEnterActive = props.onEnterActive,
      onEnterEnd = props.onEnterEnd,
      onLeave = props.onLeave,
      onLeaveActive = props.onLeaveActive,
      onLeaveEnd = props.onLeaveEnd;
  var nodeRef = React.useRef();

  var _React$useState = React.useState(TransitionState.UNMOUNTED),
      _React$useState2 = (0, _slicedToArray2.default)(_React$useState, 2),
      state = _React$useState2[0],
      setState = _React$useState2[1];

  var callbackRef = React.useRef(_utils.noop);
  var unmounted = TransitionState.UNMOUNTED === state;
  var enter = TransitionState.ENTER === state;
  var entering = TransitionState.ENTERING === state;
  var leave = TransitionState.EXIT === state;
  var leaving = TransitionState.EXITING === state;
  var exited = TransitionState.EXITED === state;
  var running = enter || entering || leave || leaving;
  var className = (0, _classnames2.default)((_classnames = {}, (0, _defineProperty2.default)(_classnames, "".concat(tranisitionName, "-enter"), enter || entering), (0, _defineProperty2.default)(_classnames, "".concat(tranisitionName, "-enter-active"), entering), (0, _defineProperty2.default)(_classnames, "".concat(tranisitionName, "-leave"), leave || leaving), (0, _defineProperty2.default)(_classnames, "".concat(tranisitionName, "-leave-active"), leaving), _classnames));
  var timeout = running && duration && duration > 0 ? "".concat(props.duration, "ms") : undefined;
  var style = {
    animationDuration: timeout,
    WebkitAnimationDuration: timeout,
    transitionDuration: timeout,
    WebkitTransitionDuration: timeout,
    display: (unmounted || exited) && !visible && !destroy ? 'none' : undefined
  };

  var setNodeRef = function setNodeRef(node) {
    nodeRef.current = node;
  };

  React.useImperativeHandle(props.nodeRef, function () {
    return nodeRef.current;
  });
  React.useEffect(function () {
    return function () {
      if (!nodeRef.current) return;

      _events.default.off(nodeRef.current, animationEndName, callbackRef.current);

      _events.default.off(nodeRef.current, transitionEndName, callbackRef.current);
    };
  }, []);
  return /*#__PURE__*/React.createElement(_reactTransitionGroup.Transition, {
    nodeRef: nodeRef,
    in: visible,
    addEndListener: function addEndListener(next) {
      if (!nodeRef.current) return;

      callbackRef.current = function (event) {
        var target = event.target;
        if (!target.contains(nodeRef.current)) return;
        next();
      };

      _events.default.on(nodeRef.current, animationEndName, callbackRef.current);

      _events.default.on(nodeRef.current, transitionEndName, callbackRef.current);
    },
    mountOnEnter: !forceRender,
    unmountOnExit: destroy,
    onEnter: function onEnter() {
      setState(TransitionState.ENTER);
      _onEnter === null || _onEnter === void 0 ? void 0 : _onEnter();
    },
    onEntering: function onEntering() {
      setState(TransitionState.ENTERING);
      onEnterActive === null || onEnterActive === void 0 ? void 0 : onEnterActive();
    },
    onEntered: function onEntered() {
      setState(TransitionState.ENTERED);
      onEnterEnd === null || onEnterEnd === void 0 ? void 0 : onEnterEnd();
    },
    onExit: function onExit() {
      setState(TransitionState.EXIT);
      onLeave === null || onLeave === void 0 ? void 0 : onLeave();
    },
    onExiting: function onExiting() {
      setState(TransitionState.EXITING);
      onLeaveActive === null || onLeaveActive === void 0 ? void 0 : onLeaveActive();
    },
    onExited: function onExited() {
      setState(TransitionState.EXITED);
      onLeaveEnd === null || onLeaveEnd === void 0 ? void 0 : onLeaveEnd();
    }
  }, function () {
    if ( /*#__PURE__*/React.isValidElement(children)) {
      return /*#__PURE__*/React.cloneElement(children, {
        ref: setNodeRef,
        className: (0, _classnames2.default)(children.props.className, className),
        style: _objectSpread(_objectSpread({}, children.props.style), style)
      });
    }

    return children === null || children === void 0 ? void 0 : children({
      className: className,
      style: style,
      visible: visible
    }, setNodeRef);
  });
};

var _default = Transition;
exports.default = _default;